@@ -54,11 +54,11 @@ static const char *__performance_level_help =
 "This indicates the current Performance Level of the GPU.";
 
 static const char *__performance_mode_short_help =
-"This indicates the current Performance Mode of the GPU.\n";
+"This indicates the current Performance Mode of the GPU.";
 
 static const char *__performance_mode_help =
-"This indicates the current Performance Mode of the GPU.\n"
-"Performance Mode can be either \"Desktop\" or\n"
+"This indicates the current Performance Mode of the GPU. "
+"Performance Mode can be either \"Desktop\" or "
 "\"Maximum Performance\".";
 
 static const char *__gpu_clock_freq_help =
@@ -604,12 +604,12 @@ GtkTextBuffer *ctk_powermizer_create_help(GtkTextTagTable *table,
     ctk_help_heading(b, &i, "Adaptive Clocking");
     ctk_help_para(b, &i, __adaptive_clock_help);
 
-    ctk_help_heading(b, &i, "Power Source");
-    ctk_help_para(b, &i, __power_source_help);
-
     ctk_help_heading(b, &i, "Clock Frequencies");
     ctk_help_para(b, &i, __clock_freq_help);
 
+    ctk_help_heading(b, &i, "Power Source");
+    ctk_help_para(b, &i, __power_source_help);
+
     ctk_help_heading(b, &i, "Performance Level");
     ctk_help_para(b, &i, __performance_level_help);
 
